#!/usr/bin/env python3
# -*- encoding=utf-8 -*-

# description:
# author:jack
# create_time: 2018/5/28

"""
    desc:pass
"""
from dueros.directive.AudioPlayer.Control.Button import Button

class RecommendButton(Button):

    def __init__(self):
        super(RecommendButton, self).__init__('RECOMMEND')

    pass


if __name__ == '__main__':
    pass