#!/usr/bin/env python3
# -*- encoding=utf-8 -*-

# description:
# author:jack
# create_time: 2017/12/31 上午12:24

"""
    desc:pass
"""


class __init__:

    pass


if __name__ == '__main__':
    pass