#!/usr/bin/env python3
# -*- encoding=utf-8 -*-

# description:
# author:jack
# create_time: 2018/5/28

"""
    desc:pass
"""

from dueros.directive.AudioPlayer.Control.Button import Button

class PreviousButton(Button):

    def __init__(self):
        super(PreviousButton, self).__init__('PREVIOUS')


if __name__ == '__main__':
    pass